@@ -243,6 +243,7 @@ require AutoLoader;
 	SQL_ATTR_ROW_NUMBER
 	SQL_ATTR_ROW_OPERATION_PTR
 	SQL_ATTR_ROW_STATUS_PTR
+        SQL_ATTR_SET_SCHEMA
 	SQL_ATTR_SIMULATE_CURSOR
 	SQL_ATTR_STMTTXN_ISOLATION
 	SQL_ATTR_SYNC_POINT
@@ -1551,6 +1552,7 @@ require AutoLoader;
 	SQL_WCHARTYPE_CONVERT
 	SQL_WCHARTYPE_DEFAULT
 	SQL_WCHARTYPE_NOCONVERT
+        SQL_XML
 	SQL_XOPEN_CLI_YEAR
 	SQL_YEAR
 	SQL_YEAR_TO_MONTH
